@@ -417,9 +417,9 @@ class AbstractElement:
     * ``previous_siblings()``
     * ``next_siblings()``
 
-    If you wrap other objects, be sure to reimplement __eq__ and __ne__, to
-    compare those objects and not the wrappers, which may be recreated each
-    time.
+    If you wrap other objects, be sure to reimplement ``__eq__`` and
+    ``__ne__``, to compare those objects and not the wrappers, which may be
+    recreated each time.
 
     """
 
